@@ -35,8 +35,11 @@
 
 @class NSString;
 @class NSArray;
+@class NSIndexPath;
+@class NSIndexSet;
 
 @class NSCell;
+@class NSEvent;
 @class NSMatrix;
 @class NSScroller;
 //@class NSBox;
@@ -127,6 +130,17 @@ typedef NSUInteger NSBrowserColumnResizingType;
 - (void) setReusesColumns: (BOOL)flag;
 - (void) setTakesTitleFromPreviousColumn: (BOOL)flag;
 - (BOOL) takesTitleFromPreviousColumn;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (BOOL) autohidesScroller;
+- (void) setAutohidesScroller: (BOOL)flag;
+- (NSColor *) backgroundColor;
+- (void) setBackgroundColor: (NSColor *)backgroundColor;
+#endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (BOOL) canDragRowsWithIndexes: (NSIndexSet *)rowIndexes
+                       inColumn: (NSInteger)columnIndex
+                      withEvent: (NSEvent *)dragEvent;
+#endif
 
 //
 // Allowing Different Types of Selection 
@@ -146,6 +160,11 @@ typedef NSUInteger NSBrowserColumnResizingType;
 - (void) setAcceptsArrowKeys: (BOOL)flag;
 - (void) setSendsActionOnArrowKeys: (BOOL)flag;
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (BOOL) allowsTypeSelect;
+- (void) setAllowsTypeSelect: (BOOL)allowsTypeSelection;
+#endif
+
 //
 // Showing a Horizontal Scroller 
 //
@@ -186,6 +205,12 @@ typedef NSUInteger NSBrowserColumnResizingType;
 - (NSInteger) selectedRowInColumn: (NSInteger)column;
 - (void) setLastColumn: (NSInteger)column;
 - (void) validateVisibleColumns;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (NSIndexPath *) selectionIndexPath;
+- (NSArray *) selectionIndexPaths;
+- (void) setSelectionIndexPath: (NSIndexPath *)path;
+- (void) setSelectionIndexPaths: (NSArray *)paths;
+#endif
 
 //
 // Manipulating Column Titles 
@@ -222,6 +247,10 @@ typedef NSUInteger NSBrowserColumnResizingType;
 //
 - (void) doClick: (id)sender;
 - (void) doDoubleClick: (id)sender;
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST)
+- (NSInteger) clickedColumn;
+- (NSInteger) clickedRow;
+#endif
 
 //
 // Getting Matrices and Cells 
@@ -277,7 +306,7 @@ typedef NSUInteger NSBrowserColumnResizingType;
 // Controlling the alphanumerical keys behaviour
 //
 @interface NSBrowser (GNUstepExtensions)
-- (BOOL)acceptsAlphaNumericalKeys;
+- (BOOL) acceptsAlphaNumericalKeys;
 - (void) setAcceptsAlphaNumericalKeys: (BOOL)flag;
 - (BOOL) sendsActionOnAlphaNumericalKeys;
 - (void) setSendsActionOnAlphaNumericalKeys: (BOOL)flag;
@@ -286,7 +315,13 @@ typedef NSUInteger NSBrowserColumnResizingType;
 //
 // Methods Implemented by the Delegate 
 //
+@protocol NSBrowserDelegate <NSObject>
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_6, GS_API_LATEST) && GS_PROTOCOLS_HAVE_OPTIONAL
+@optional
+#else
+@end
 @interface NSObject (NSBrowserDelegate)
+#endif
 
 - (void) browser: (NSBrowser *)sender createRowsForColumn: (NSInteger)column
   inMatrix: (NSMatrix *)matrix;
@@ -313,6 +348,12 @@ typedef NSUInteger NSBrowserColumnResizingType;
 sizeToFitWidthOfColumn: (NSInteger)column;
 - (void) browserColumnConfigurationDidChange: (NSNotification *)notification;
 #endif
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+- (BOOL) browser: (NSBrowser *)browser
+canDragRowsWithIndexes: (NSIndexSet *)rowIndexes
+        inColumn: (NSInteger)column
+       withEvent: (NSEvent *)event;
+#endif
 @end
 
 #if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
