@@ -32,11 +32,13 @@
 #ifndef _GNUstep_H_GSTextConverter
 #define _GNUstep_H_GSTextConverter
 
-#include <Foundation/NSAttributedString.h>
-#include <Foundation/NSDictionary.h>
-#include <Foundation/NSData.h>
-#include <AppKit/NSFileWrapper.h>
+#import <Foundation/NSObject.h>
 
+@class NSAttributedString;
+@class NSData;
+@class NSDictionary;
+@class NSError;
+@class NSString;
 
 @protocol GSTextConverter
 + (Class) classForFormat: (NSString*)format 
@@ -45,9 +47,8 @@
 
 @protocol GSTextProducer
 + (NSData*) produceDataFrom: (NSAttributedString*) aText
-	 documentAttributes: (NSDictionary*)dict;
-+ (NSFileWrapper*) produceFileFrom: (NSAttributedString*) aText
-		documentAttributes: (NSDictionary*)dict;
+	 documentAttributes: (NSDictionary*)dict
+                      error: (NSError **)error;
 @end
 
 /* 
@@ -57,10 +58,9 @@
  */
 @protocol GSTextConsumer
 + (NSAttributedString*) parseData: (NSData *)aData 
+                          options: (NSDictionary *)options
 	       documentAttributes: (NSDictionary **)dict
-			    class: (Class)class;
-+ (NSAttributedString*) parseFile: (NSFileWrapper *)aFile 
-	       documentAttributes: (NSDictionary **)dict
+                            error: (NSError **)error
 			    class: (Class)class;
 @end
 
