@@ -204,7 +204,11 @@
 	  A theme subclass may override the -imageClass method to change the
 	  class used to load each image from the bundle ... thus allowing
 	  customisation of not just the images but also of the image
-	  behavior in the (very rare) cases where this is desirable.
+	  behavior in the (very rare) cases where this is desirable.<br />
+          Finally, a theme may provide application specific images which are
+          loaded <em>in preference to</em> named images from the application's
+          own bundle.  These images are simply stored in a subdirectory whose
+          name is the same as the application's bundleIdentifier.
 	</desc>
       </deflist>
     </section>
@@ -217,6 +221,7 @@
 
 #import <Foundation/NSObject.h>
 #import <Foundation/NSGeometry.h>
+#import <AppKit/NSBox.h>
 #import <AppKit/NSCell.h>
 // For gradient types
 #import <AppKit/NSButtonCell.h>
@@ -226,23 +231,32 @@
 #import <AppKit/NSScroller.h>
 // For segmented control style constants
 #import <AppKit/NSSegmentedControl.h>
+// For tab view type 
+#import <AppKit/NSTabView.h>
+#import <AppKit/NSPrintPanel.h>
+#import <AppKit/NSPageLayout.h>
 
 #if	OS_API_VERSION(GS_API_NONE,GS_API_NONE)
 @class NSArray;
 @class NSBundle;
+@class NSBrowserCell;
 @class NSDictionary;
-
 @class NSButton;
 @class NSColor;
 @class NSColorList;
 @class NSColorWell;
 @class NSImage;
 @class NSMenuItemCell;
+@class NSPopUpButtonCell;
 @class NSMenuView;
 @class NSProgressIndicator;
 @class NSTableHeaderCell;
 @class NSTabViewItem;
 @class GSDrawTiles;
+@class GSTitleView;
+
+APPKIT_EXPORT	NSString	*GSSwitch;
+APPKIT_EXPORT   NSString        *GSRadio;
 
 /* First, declare names used for obtaining colors and/or tiles for specific
  * controls and parts of controls.
@@ -274,19 +288,47 @@ APPKIT_EXPORT  NSString        *GSBrowserHeader;
  */
 APPKIT_EXPORT  NSString        *GSMenuHorizontalBackground;
 APPKIT_EXPORT  NSString        *GSMenuVerticalBackground;
+APPKIT_EXPORT  NSString        *GSMenuTitleBackground;
 APPKIT_EXPORT  NSString        *GSMenuHorizontalItem;
 APPKIT_EXPORT  NSString        *GSMenuVerticalItem;
 APPKIT_EXPORT  NSString        *GSMenuSeparatorItem;
 
+/* NSPopUpButton parts */
+
+APPKIT_EXPORT  NSString        *GSPopUpButton;
+
 /*
  * Progress Indicator part names.
  */
+APPKIT_EXPORT  NSString        *GSProgressIndicatorBezel;
 APPKIT_EXPORT  NSString        *GSProgressIndicatorBarDeterminate;
 
 /*
  * Color well part names.
  */
 APPKIT_EXPORT  NSString        *GSColorWell;
+APPKIT_EXPORT  NSString        *GSColorWellInnerBorder;
+
+/* NSSliderCell parts */
+APPKIT_EXPORT  NSString        *GSSliderHorizontalTrack;
+APPKIT_EXPORT  NSString        *GSSliderVerticalTrack;
+
+/* NSBox parts */
+APPKIT_EXPORT  NSString        *GSBoxBorder;
+
+/* NSTabView parts */
+APPKIT_EXPORT  NSString        *GSTabViewSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewUnSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewBackgroundTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewBottomSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewBottomUnSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewBottomBackgroundTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewLeftSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewLeftUnSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewLeftBackgroundTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewRightSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewRightUnSelectedTabFill;
+APPKIT_EXPORT  NSString        *GSTabViewRightBackgroundTabFill;
 
 /**
  * Structure to describe the size of top/bottom/left/right margins inside
@@ -339,8 +381,11 @@ GSThemeFillStyleFromString(NSString *s);
  */
 typedef enum {
   GSThemeNormalState = 0,	/** A control in its normal state */
+  GSThemeFirstResponderState,
   GSThemeDisabledState,		/** A control which is disabled */
+  GSThemeHighlightedFirstResponderState,
   GSThemeHighlightedState,	/** A control which is highlighted */
+  GSThemeSelectedFirstResponderState,
   GSThemeSelectedState		/** A control which is selected */
 } GSThemeControlState;
 
@@ -709,6 +754,11 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (NSString*) versionString;
 
+/**
+ * Return the theme's license.
+ */
+- (NSString*) license;
+
 @end
 
 /**
@@ -730,6 +780,13 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 @interface	GSTheme (Drawing)
 
+/**
+ * Allows the theme to set an image or set attributes for drawing the
+ * button differently based on the key equivalent which is set.
+ */
+- (void) setKeyEquivalent: (NSString *)key 
+            forButtonCell: (NSButtonCell *)cell;
+
 /**
  * Draws a button frame and background (not its content) for the specified
  * cell and view.
@@ -783,6 +840,23 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (NSSize) sizeForImageFrameStyle: (NSImageFrameStyle)frameStyle;
 
+/**
+ * Return YES if the scroller arrows are at the same end.
+ * Return NO to get one scroller arrow at each end of the scroller.
+ *
+ * The default implementation first checks the default GSScrollerArrowsSameEnd
+ * and if that is not set, delegates to the NSInterfaceStyle.
+ */
+- (BOOL) scrollerArrowsSameEndForScroller: (NSScroller *)aScroller;
+
+/**
+ * Returns YES if clicking in the scroller slot should scroll by one page,
+ * NO if the scroller should jump to the location clicked.
+ *
+ * The default implementation first checks the default GSScrollerScrollsByPage
+ * and if that is not set, delegates to the NSInterfaceStyle.
+ */
+- (BOOL) scrollerScrollsByPageForScroller: (NSScroller *)aScroller;
 
 /** 
  * Creates and returns the cell to be used to draw a scroller arrow of the
@@ -821,6 +895,23 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (float) defaultScrollerWidth;
 
+/**
+ * If YES, instructs NSScrollView to leave an empty square space where
+ * the horizontal and vertical scrollers meet.
+ * 
+ * Controlled by user default GSScrollViewUseBottomCorner; default YES.
+ */
+- (BOOL) scrollViewUseBottomCorner;
+
+/**
+ * If YES, instructs NSScrollView to make the scrollers overlap the border.
+ * The scroll view border is drawn using the NSScrollView part, which
+ * must be provided by the theme if this method returns YES.
+ * 
+ * Controlled by user default GSScrollViewScrollersOverlapBorders; default NO;
+ */
+- (BOOL) scrollViewScrollersOverlapBorders;
+
 /** 
  * Method for toolbar theming.
  */
@@ -957,6 +1048,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
                                          inView: (NSView *)controlView
                                           state: (GSThemeControlState)state
                                    isHorizontal: (BOOL)isHorizontal;
+
 /**
  * <p>Draws the menu item title.</p>
  *
@@ -965,8 +1057,10 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  *
  * <p>The title color is mapped to the theme state as described below:</p>
  * <deflist>
- * <item>GSThemeSelectedState</item><desc>[NSColor+selectedMenuItemTextColor]</desc>
- * <item>GSThemeDisabledState</item><desc>[NSColor+controlTextColor] or 
+ * <term>GSThemeSelectedState</term>
+ * <desc>[NSColor+selectedMenuItemTextColor]</desc>
+ * <term>GSThemeDisabledState</term>
+ * <desc>[NSColor+controlTextColor] or 
  * [NSColor+disabledControlTextColor]</desc>
  * </deflist>
  */
@@ -988,7 +1082,8 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (NSColor *) menuSeparatorColor;
 /**
- * <p>Returns the left and right inset used to draw a separator line in a menu.</p>
+ * <p>Returns the left and right inset used to draw a separator line in a
+ * menu.</p>
  *
  * <p>By default, returns 3.0.</p>
  *
@@ -998,6 +1093,22 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * <p>Can be overridden in subclasses to return a custom value.</p>
  */
 - (CGFloat) menuSeparatorInset;
+
+/**
+ * Amount that submenus overlap their parent menu by, horizontally.
+ * (i.e. applies to vertical menus)
+ *
+ * Controlled by GSMenuSubmenuHorizontalOverlap default
+ */
+- (CGFloat) menuSubmenuHorizontalOverlap;
+
+/**
+ * Amount that submenus overlap the horizontal menu bar by, vertically.
+ *
+ * Controlled by GSMenuSubmenuVerticalOverlap default
+ */
+- (CGFloat) menuSubmenuVerticalOverlap;
+
 /**
  * <p>Draws a separator between normal menu items in a menu.</p>
  *
@@ -1005,7 +1116,7 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  * -isSeparatorItem</p>
  *
  * <p>You can provide an image tile named <em>GSMenuSeparatorItem</em> to 
- * draw the separator.</br>
+ * draw the separator.<br />
  * Can be overridden in subclasses to customize the drawing.</p>
  *
  * <p>See also -menuSeparatorColor and -menuSeparatorInset</p>
@@ -1022,6 +1133,14 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
  */
 - (Class) titleViewClassForMenuView: (NSMenuView *)aMenuView;
 
+- (NSRect) drawMenuTitleBackground: (GSTitleView *)aTitleView
+			withBounds: (NSRect)bounds
+			  withClip: (NSRect)clipRect;
+
+- (CGFloat) menuBarHeight;
+- (CGFloat) menuItemHeight;
+- (CGFloat) menuSeparatorHeight;
+
 // NSColorWell drawing method
 - (NSRect) drawColorWellBorder: (NSColorWell*)well
                     withBounds: (NSRect)bounds
@@ -1038,6 +1157,8 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 - (void) drawProgressIndicatorBarDeterminate: (NSRect)bounds;
 
 // Table drawing methods
+- (NSColor *) tableHeaderTextColorForState: (GSThemeControlState)state;
+
 - (void) drawTableCornerView: (NSView*)cornerView
                     withClip: (NSRect)aRect;
 - (void) drawTableHeaderCell: (NSTableHeaderCell *)cell
@@ -1049,12 +1170,22 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 
 - (float) resizebarHeight;
 
+- (float) titlebarButtonSize;
+
+- (float) titlebarPaddingRight;
+
+- (float) titlebarPaddingTop;
+
+- (float) titlebarPaddingLeft;
+
 - (void) drawWindowBorder: (NSRect)rect
                 withFrame: (NSRect)frame 
              forStyleMask: (unsigned int)styleMask
                     state: (int)inputState
                  andTitle: (NSString*)title;
 
+- (NSColor *) browserHeaderTextColor;
+
 - (void) drawBrowserHeaderCell: (NSTableHeaderCell*)cell
 		     withFrame: (NSRect)rect
 			inView: (NSView*)view;
@@ -1062,6 +1193,10 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 - (NSRect) browserHeaderDrawingRectForCell: (NSTableHeaderCell*)cell
 				 withFrame: (NSRect)rect;
 
+- (NSRect) tabViewContentRectForBounds: (NSRect)aRect
+			   tabViewType: (NSTabViewType)type
+			       tabView: (NSTabView *)view;
+
 - (void) drawTabViewRect: (NSRect)rect
 		  inView: (NSView *)view
 	       withItems: (NSArray *)items
@@ -1077,6 +1212,12 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 	withScrollerRect: (NSRect)scrollerRect
 	      columnSize: (NSSize)columnSize;
 
+- (CGFloat) browserColumnSeparation;
+
+- (CGFloat) browserVerticalPadding;
+
+- (BOOL) browserUseBezels;
+
 - (void) drawMenuRect: (NSRect)rect
 	       inView: (NSView *)view
 	 isHorizontal: (BOOL)horizontal
@@ -1085,6 +1226,11 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 - (void) drawScrollViewRect: (NSRect)rect
 	             inView: (NSView *)view;
 
+- (void) drawSliderBorderAndBackground: (NSBorderType)aType
+				 frame: (NSRect)cellFrame
+				inCell: (NSCell *)cell
+			  isHorizontal: (BOOL)horizontal;
+
 - (void) drawBarInside: (NSRect)rect
 		inCell: (NSCell *)cell
 	       flipped: (BOOL)flipped;
@@ -1114,9 +1260,14 @@ APPKIT_EXPORT	NSString	*GSThemeWillDeactivateNotification;
 					inView: (NSView *)view
 			      selectingColumns: (BOOL)selectingColumns;
 
-- (void) drawTableViewRow: (int)rowIndex 
+- (void) drawTableViewRow: (NSInteger)rowIndex 
 		 clipRect: (NSRect)clipRect
 		   inView: (NSView *)view;
+
+- (void) drawBoxInClipRect: (NSRect)clipRect
+		   boxType: (NSBoxType)boxType
+		borderType: (NSBorderType)borderType
+		    inView: (NSBox *)box;
 @end
 
 /**
@@ -1216,6 +1367,9 @@ withRepeatedImage: (NSImage*)image
 	  withTiles: (GSDrawTiles*)tiles
 	 background: (NSColor*)color;
 
+- (NSRect) fillRect: (NSRect)rect
+	  withTiles: (GSDrawTiles*)tiles;
+
 /**
  * Method to tile the supplied image to fill the vertical rectangle.<br />
  * The rect argument is the rectangle to be filled.<br />
@@ -1297,5 +1451,81 @@ withRepeatedImage: (NSImage*)image
 - (Class) savePanelClass;
 @end
 
+// Panels which can be overridden by the theme...
+@interface GSPrintPanel : NSPrintPanel
+@end
+
+@interface GSPageLayout : NSPageLayout
+@end
+
+@interface GSTheme (PrintPanels)
+/**
+ * This method returns the print panel class needed by the
+ * native environment.
+ */
+- (Class) printPanelClass;
+
+/**
+ * This method returns the page layout class needed by the 
+ * native environment.
+ */
+- (Class) pageLayoutClass;
+@end
+
+@interface GSTheme (NSWindow)
+/**
+ * This method returns the standard window button for the
+ * given mask for the current theme.
+ */ 
+- (NSButton *) standardWindowButton: (NSWindowButton)button
+		       forStyleMask: (NSUInteger) mask;
+				  
+/** 
+ * This method does any additional setup after the default 
+ * cell is set.
+ */
+- (void) didSetDefaultButtonCell: (NSButtonCell *)aCell;
+@end
+					 
+@interface GSTheme (NSBrowserCell)
+/** 
+ * Draw editor in cell
+ */
+- (void) drawEditorForCell: (NSCell *)cell
+		 withFrame: (NSRect)cellFrame
+	       	    inView: (NSView *)view;
+
+/** 
+ * Draw attributed text in cell
+ */
+- (void) drawInCell: (NSCell *)cell
+     attributedText: (NSAttributedString *)stringValue
+	    inFrame: (NSRect)cellFrame;
+
+/** 
+ * Draw the interior of the browser cell
+ */
+- (void) drawBrowserInteriorWithFrame: (NSRect)cellFrame 
+			     withCell: (NSBrowserCell *)cell
+			       inView: (NSView *)controlView
+			    withImage: (NSImage *)theImage
+		       alternateImage: (NSImage *)alternateImage
+			isHighlighted: (BOOL)isHighlighted
+				state: (int)state
+			       isLeaf: (BOOL)isLeaf;
+
+/** 
+ * This method returns the branch image
+ */
+- (NSImage *) branchImage;
+
+/** 
+ * This method returns the highlighted version of 
+ * the branch image
+ */
+- (NSImage *) highlightedBranchImage;
+@end
+
+
 #endif /* OS_API_VERSION */
 #endif /* _GNUstep_H_GSTheme */
